@@ -1,9 +1,10 @@
 package PMLTQ::Command::query;
 our $AUTHORITY = 'cpan:MATY';
-$PMLTQ::Command::query::VERSION = '1.2.2';
+$PMLTQ::Command::query::VERSION = '1.2.3';
 # ABSTRACT: WIP: Executes query on treebank
 
 use PMLTQ::Base 'PMLTQ::Command';
+use PMLTQ;
 use Cwd;
 use File::Spec;
 
@@ -16,6 +17,7 @@ use HTTP::Request::Common;
 use LWP::UserAgent;
 use File::Temp;
 use Encode;
+use Pod::Usage 'pod2usage';
 
 my $extension_dir;
 my %opts;
@@ -572,7 +574,7 @@ PMLTQ::Command::query - WIP: Executes query on treebank
 
 =head1 VERSION
 
-version 1.2.2
+version 1.2.3
 
 =head1 SYNOPSIS
 
