@@ -1,6 +1,6 @@
 package PMLTQ::Relation::PDT;
 our $AUTHORITY = 'cpan:MATY';
-$PMLTQ::Relation::PDT::VERSION = '1.2.2';
+$PMLTQ::Relation::PDT::VERSION = '1.2.3';
 # ABSTRACT: PDT user defined relations
 
 use warnings;
@@ -209,6 +209,22 @@ sub TGetEChildren { # node
   return @sons;
 } # TGetEChildren
 
+
+
+
+sub ThisAddress {
+  my ($node) = @_;
+  my $type = $node->type;
+  my ($id_attr) = $type && $type->find_members_by_role('#ID');
+
+  return  '#' . $node->{ $id_attr->get_name }
+}
+
+sub ThisAddressNTRED {
+  my ($node) = @_;
+  return  '#???'
+}
+
 1;
 
 __END__
@@ -223,7 +239,7 @@ PMLTQ::Relation::PDT - PDT user defined relations
 
 =head1 VERSION
 
-version 1.2.2
+version 1.2.3
 
 =over 5
 
